//
// Copyright (c) 2012, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.Generic;
using System.Drawing;
using System.Windows.Forms;
using System.Xml;

using MindFusion.Diagramming;
using MindFusion.Diagramming.Layout;


namespace MindFusion.Diagramming.WinForms.Samples.CS.Tutorial1
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();

			diagram.BackBrush = new MindFusion.Drawing.SolidBrush(Color.White);
			diagram.LinkHeadShapeSize = 3;
		}

		protected override void OnLoad(EventArgs e)
		{
			base.OnLoad(e);

			Dictionary<string, DiagramNode> nodeMap = new Dictionary<string, DiagramNode>();
			RectangleF bounds = new RectangleF(0, 0, 18, 6);

			// Load the graph xml
			XmlDocument document = new XmlDocument();
			document.Load("SampleGraph.xml");

			// Load node data
			XmlNodeList nodes = document.SelectNodes("/Graph/Nodes/Node");
			foreach (XmlElement node in nodes)
			{
				ShapeNode diagramNode = diagram.Factory.CreateShapeNode(bounds);
                diagramNode.Brush = new MindFusion.Drawing.LinearGradientBrush(Color.FromArgb(224, 233, 233),
                    Color.FromArgb(90, 121, 165));
                diagramNode.Pen = new MindFusion.Drawing.Pen(Color.FromArgb(0, 52, 102));
				nodeMap[node.GetAttribute("id")] = diagramNode;
				diagramNode.Text = node.GetAttribute("name");
			}

			// Load link data
			XmlNodeList links = document.SelectNodes("/Graph/Links/Link");
			foreach (XmlElement link in links)
			{
				DiagramLink dLink = diagram.Factory.CreateDiagramLink(
					nodeMap[link.GetAttribute("origin")],
					nodeMap[link.GetAttribute("target")]);
                dLink.Pen = new MindFusion.Drawing.Pen(Color.FromArgb(0, 52, 102));
                dLink.HeadPen = new MindFusion.Drawing.Pen(Color.FromArgb(0, 52, 102));

			}

			// Arrange the graph
			LayeredLayout layout = new LayeredLayout();
			layout.LayerDistance = 12;
			layout.Arrange(diagram);
		}
	}
}
